SUNWEG_URL = 'https://api.sun.weg.net/'
SUNWEG_LOGIN_PATH = 'login/autenticacao'
SUNWEG_PLANT_LIST_PATH = 'usinas/getpaineloperacao?procurar=&integrador=&franqueado=&portal=&alarme=&planos=%5B%220%22,%221%22,%222%22,%223%22,%224%22%5D&status=%5B%221%22,%222%22,%223%22,%224%22,%225%22%5D'
SUNWEG_PLANT_DETAIL_PATH = 'usinas/view?idusina='
SUNWEG_INVERTER_DETAIL_PATH = 'inversores/view?id='